#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const clipboardy = __importStar(require("clipboardy"));
const parseArgs = require("minimist");
const camelize = require("camelize");
const break_tweet_autolink_1 = require("break-tweet-autolink");
if (process.argv.length === 3 && (process.argv[2] === '--help' || process.argv[2] === '-h')) {
    console.log(`Usage: break-tweet-autolink [OPTS... --] <ARGS>

This is a CLI utility to break auto links in Twitter text. <ARGS> are text you
want to convert. If multiple arguments are given, they are concatenated with
' '. If no argument is given, text is retrieved from your system clipboard.

By default, only URLs with no scheme and cashtags are unlinked.

If you want to add some options, '--' argument must be followed after the last
option even if no argument is specified.

OPTS:

--url-no-scheme,  --no-url-no-scheme
	URL with no scheme such as foo.com (default: true)

--url-with-scheme,  --no-url-with-scheme
	URL with scheme such as https://foo.com (default: false)

--mention,  --no-mention
	Screen name such as @foo (default: false)

--list,  --no-list
	List mention such as @foo/bar (default: false)

--hashtag,  --no-hashtag
	Hashtags such as #foo (default: false)

--cashtag,  --no-cashtag
	Cashtags such as $FOO (default: true)
`);
    process.exit(0);
}
function getOptsAndArgs() {
    const args = process.argv.slice(2);
    const optsSepIndex = args.indexOf('--');
    if (optsSepIndex === -1) {
        return [[], args];
    }
    else {
        return [args.slice(0, optsSepIndex), args.slice(optsSepIndex + 1)];
    }
}
function getText(args) {
    return __awaiter(this, void 0, void 0, function* () {
        if (args.length > 0) {
            return args.join(' ');
        }
        else {
            return yield clipboardy.read();
        }
    });
}
function getConfig(opts) {
    if (opts.length === 0) {
        return null;
    }
    return camelize(parseArgs(opts));
}
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        const [opts, args] = getOptsAndArgs();
        const input = yield getText(args);
        const breaker = new break_tweet_autolink_1.TweetAutoLinkBreaker(getConfig(opts));
        const output = breaker.breakAutoLinks(input);
        process.stdout.write(output);
    });
}
main().catch(console.error);
//# sourceMappingURL=main.js.map